#
# spec file for package snipl
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           snipl
Url:            http://www.ibm.com/developerworks/linux/linux390/snipl.html
Version:        0.3.0.0
Release:        lp154.1.4
Summary:        Simple Network IPL
License:        CPL-1.0 and SUSE-NonFree
Group:          System/Management
BuildRequires:  dos2unix
BuildRequires:  glib2-devel
BuildRequires:  libglue-devel
BuildRequires:  libopenssl-devel
%if 0%{?suse_version} >= 1130
BuildRequires:  libnet-devel
BuildRequires:  libnsl-devel
BuildRequires:  libtool
%else
BuildRequires:  libnet
%endif
%define api_ver 2.13.1-27
%ifarch %{ix86}
%define api_arch i686
%else
%define api_arch %{_arch}
%endif
ExclusiveArch:  s390 s390x x86_64
Source:         %name-%{version}.tar.gz
Source1:        hwmcaapi-rpms-%{api_ver}.tbz
Source2:        Z125-5589-05.txt
Source99:       hwmcaapi.download
Patch1:         snipl-0.3.0.0-hwmcaapidir.patch
Patch2:         snipl-sles15-openssl11.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
snIPL - simple network IPL (Linux Image Control for LPAR / VM) - is
a command line tool which serves as remote Linux image control using
basic Support Element (SE) functions or basic z/VM system management
functions on one or more images.

%prep
%setup
%patch1 -p1
%patch2 -p1

cp -p %SOURCE2 .
mkdir hwmcaapi
pushd hwmcaapi
tar -O -xvf %SOURCE1 hwmcaapi-%{api_ver}.%{api_arch}.rpm  | \
       rpm2cpio | cpio -idmv "./usr/share/doc/*"
tar -O -xvf %SOURCE1 hwmcaapi-devel-%{api_ver}.%{api_arch}.rpm  | \
       rpm2cpio | cpio -idmv
popd

dos2unix -o README.snipl

%build
export CFLAGS="%{optflags} $(pkg-config --libs libnsl)"
make HWMCAAPI_DIR="$PWD/hwmcaapi"

%install
make install PREFIX="%{buildroot}/%{_prefix}" \
	LIB_STRING="%{_lib}" HWMCAAPI_DIR="$PWD/hwmcaapi"

cp -a hwmcaapi/%{_libdir}/*.so* $RPM_BUILD_ROOT/%{_libdir}
rm -f "%{buildroot}/%{_libdir}/stonith/plugins/stonith2"/*.la
rm -f "%{buildroot}/%{_libdir}/stonith/plugins/stonith2"/*.a

%files
%defattr(-,root,root)
%doc LICENSE README.snipl Z125-5589-05.txt
%{_libdir}/*.so*
%{_libdir}/stonith/plugins/stonith2/*.so
%{_bindir}/*
%doc %{_mandir}/man8/*%{ext_man}

%changelog
* Mon Dec 11 2017 mpost@suse.com
- Added snipl-sles15-openssl11.patch (bsc#1071405).
  snipl fails to compile against openssl 1.1.0
* Thu Sep 21 2017 mpost@suse.com
- Remove deprecated DMSVSMA functionality from snIPL. (Fate#322117)
  - Removed the dmsvsma.x file from the build.
  - Removed all DMSVSMA references from the spec file.
* Tue Sep 12 2017 mpost@suse.com
- Modifed CFLAGS to include "pkg-config --libs libnsl" now that
  libnsl.so is not part of glibc, and is in /usr/lib64/nsl/.
- Added a BuildRequires for libsnl-devel.
* Thu Jan 26 2017 jengelh@inai.de
- Remove ancient sections and replace old rpm macros
* Wed Jan 25 2017 mpost@suse.com
- Upgraded to snipl 0.3.0.0 (Fate#319579)
  - Changes:
  - Remove default password from snipl
  - Enable SNMPv3 encrypted communication with HMC/SE
  - Enable OpenSSL encrypted communication with SMAPI servers
  - Bug Fixes:
  - Improve error and command line parameter handling
  - Improve support for the x86_64 platform
  - Add support for SCSI IPL with SSID 1, 2, and 3
  - Various return-code fixes
- Reworked snipl-0.2.3.3-hwmcaapidir.patch to fit new version
  and renamed it to snipl-0.3.0.0-hwmcaapidir.patch.
- Removed the unzip package as a build requirement.
- Updated hwmcaapi.download to match the current text on IBM's
  web page.
* Tue Apr 12 2016 mpost@suse.com
- Upgraded to snipl 0.2.3.3 (Fate#319578)
- Upgraded the hwmcaapi files to version 2.13.1-27
- Removed hwmcaapi.x86_64.zip in favor of the new version
  which is packaged as an RPM.
- Added hwmcaapi files for i686.
- Updated the hwmcaapi.download file to point to the additional
  files needed for i686.
- Updated and renamed snipl-0.2.3.1-hwmcaapidir.patch to match
  the current version.
- Simplified the spec file by packing all the hwmcaapi RPMs into
  a single tarball and then using variables for the architectures
  being built.
- Removed obsolete snipl-enable-x86_64-arch.patch
* Mon Mar 23 2015 dimstar@opensuse.org
- BuildRequire libnet-devel instead of libnet: the library was
  repackaged according the shared library packaging policy.
* Tue Jan 21 2014 mpost@suse.com
- Changed the license information in the spec file to CPL-1.0 and SUSE-NonFree.
* Fri Jan 17 2014 mpost@suse.com
- Changed spec file to use dos2unix instead of sed, since the OBS
  seems to be removing the Control-M from the sed command string.
* Thu Jan 16 2014 mpost@suse.com
- New IBM version of the tarball incorporating Makefile fixes
  (bnc#855242 and bnc#856178)
  - Reworked snipl-0.2.3.1-hwmcaapidir.patch to match new version.
  - Removed snipl-makefile-fixes.patch since it's no longer needed.
* Tue Jan 14 2014 mpost@suse.com
- Upgraded to snipl 0.2.3.1 (bnc#856178).
  - Reworked snipl-0.2.3.0-hwmcaapidir.patch to match new version.
  - Renamed snipl-0.2.3.0-hwmcaapidir.patch to snipl-0.2.3.1-hwmcaapidir.patch
  - Reworked snipl-makefile-fixes.patch to match new version.
* Sat Nov 30 2013 mpost@suse.com
- Upgraded to snipl 0.2.3.0
  - (FATE # 315305: snIPL interface to control dynamic CPU capacity)
- Upgraded hwmcaapi and hwmcaapi-devel to 2.12.0-12.
- Changed the spec file to Buildrequires libglue-devel instead
  of heartbeat-devel.
- Updated the dmsvsma.x to the version from z/VM 5.4.
- Added hwmcaapi.x86_64.zip from IBM.
- Added snipl-enable-x86_64-arch.patch to that it will build on the
  x86_64 architecture also.
- Added snipl-makefile-fixes.patch to fix the Makefile so the package
  would build with the newer version of gcc and binutils.
- Changed the License in snipl.spec to the new specification of CPL-1.0
* Thu May 14 2009 uli@suse.de
- added missing license file (bnc#498414)
* Tue Feb 17 2009 uli@suse.de
- update snipl -> 0.2.1.5, hwmcaapi -> 2.10.1-76 (bnc#467547)
  - snipl stonith plugin: ignore some vmsmapi command reply complains - not
    returning an error code for them to stonith.
* Mon Dec  8 2008 uli@suse.de
- fixed BuildRequires (heartbeat-common-devel -> heartbeat-devel)
* Wed Oct 15 2008 ro@suse.de
- activate ExclusiveArch
* Wed Sep 10 2008 uli@suse.de
- update -> 0.2.1.4 (bug #420370)
  - correct configuration data handling for LPARs to allow proper password
    propagation
  - correct newline handling when sending operating system commands in LPAR
    mode
  - enhance fencing availability for stonith HA by allowing different
    image-servers for an image in a snipl configuration
* Wed Aug  6 2008 ro@suse.de
- add exclusivearch to specfile
* Mon Feb 19 2007 uli@suse.de
- update -> 0.2.1.3-v3 (fixes memleaks)
* Wed Feb  7 2007 uli@suse.de
- added missing libs (libsniplapi.so, libvmsapi.so)
* Tue Jan 23 2007 uli@suse.de
- update -> 0.2.1.3 (includes heartbeat 2 plugin)
  (update from Fate#301623)
* Wed Oct 11 2006 uli@suse.de
- intitial package (Fate#301623)
